@@ -244,6 +244,12 @@ SETTING(demURL,              "demURL",                 DEM_TILES_URL          );
 SETTING(demAuthentication,   "demAuthentication",      false                  );
 SETTING(demUsername,         "demUsername",            ""                     );
 SETTING(demPassword,         "demPassword",            ""                     );
+SETTING(hillshadingAlpha,    "hillshadingAlpha",       102                    );
+SETTING(hillshadingLightening,"hillshadingLightening", 0.2                    );
+SETTING(hillshadingBlur,     "hillshadingBlur",        3                      );
+SETTING(hillshadingAzimuth,  "hillshadingAzimuth",     315                    );
+SETTING(hillshadingAltitude, "hillshadingAltitude",    45                     );
+SETTING(hillshadingZFactor,  "hillshadingZFactor",     0.6                    );
 SETTING(useOpenGL,           "useOpenGL",              false                  );
 SETTING(enableHTTP2,         "enableHTTP2",            true                   );
 SETTING(pixmapCache,         "pixmapCache",            PIXMAP_CACHE           );
