@@ -10,7 +10,7 @@
 #include "map/filter.h"
 #include "style.h"
 #include "lblfile.h"
-#include "dem.h"
+#include "demtree.h"
 #include "rastertile.h"
 
 using namespace IMG;
@@ -422,8 +422,10 @@ void RasterTile::processPoints(QList<MapData::Point> &points,
 		if ((!label || !fnt) && !img)
 			continue;
 
+		QPoint offset = img ? style.offset() : QPoint(0, 0);
+
 		TextPointItem *item = new TextPointItem(QPoint(point.coordinates.lon(),
-		  point.coordinates.lat()), label, fnt, img, color, hcolor, 0,
+		  point.coordinates.lat()) + offset, label, fnt, img, color, hcolor, 0,
 		  ICON_PADDING);
 		if (item->isValid() && !item->collides(textItems))
 			textItems.append(item);
@@ -470,7 +472,6 @@ MatrixD RasterTile::elevation(int extend) const
 	if (_data->hasDEM()) {
 		RectC rect;
 		QList<MapData::Elevation> tiles;
-		DEMTRee tree;
 
 		for (int i = 0; i < ll.size(); i++)
 			rect = rect.united(ll.at(i));
@@ -480,14 +481,14 @@ MatrixD RasterTile::elevation(int extend) const
 		_data->elevations(rect.adjusted(0, 0, rect.width() / factor,
 		  -rect.height() / factor), _zoom, &tiles);
 
-		DEM::buildTree(tiles, tree);
+		DEMTree tree(tiles);
 		for (int i = 0; i < ll.size(); i++)
-			DEM::searchTree(tree, ll.at(i), m.at(i));
+			m.at(i) = tree.elevation(ll.at(i));
 	} else {
-		::DEM::lock();
+		DEM::lock();
 		for (int i = 0; i < ll.size(); i++)
-			m.at(i) = ::DEM::elevation(ll.at(i));
-		::DEM::unlock();
+			m.at(i) = DEM::elevation(ll.at(i));
+		DEM::unlock();
 	}
 
 	return m;
