@@ -670,48 +670,49 @@ void Style::defaultPointStyle(qreal ratio)
 	_points[0x11108] = _points[0x3008];
 
 	// Marine stuff
-	_points[0x10100] = Point(QImage(":/marine/light-major.png"));
-	_points[0x10101] = Point(QImage(":/marine/light-major.png"));
-	_points[0x10102] = Point(QImage(":/marine/light-major.png"));
-	_points[0x10103] = Point(QImage(":/marine/light-major.png"));
-	_points[0x10104] = Point(QImage(":/marine/light-major.png"));
-	_points[0x10105] = Point(QImage(":/marine/light-major.png"));
-	_points[0x10106] = Point(QImage(":/marine/light-major.png"));
-	_points[0x10107] = Point(QImage(":/marine/light-major.png"));
-	_points[0x10108] = Point(QImage(":/marine/light-major.png"));
-	_points[0x10109] = Point(QImage(":/marine/light-major.png"));
-	_points[0x1010a] = Point(QImage(":/marine/light-major.png"));
-	_points[0x10200] = Point(QImage(":/marine/buoy.png"));
-	_points[0x10201] = Point(QImage(":/marine/buoy.png"));
-	_points[0x10202] = Point(QImage(":/marine/buoy.png"));
-	_points[0x10203] = Point(QImage(":/marine/buoy.png"));
-	_points[0x10204] = Point(QImage(":/marine/buoy.png"));
-	_points[0x10205] = Point(QImage(":/marine/buoy.png"));
-	_points[0x10206] = Point(QImage(":/marine/beacon.png"));
-	_points[0x10207] = Point(QImage(":/marine/spar-buoy.png"));
-	_points[0x10209] = Point(QImage(":/marine/buoy.png"));
-	_points[0x1020a] = Point(QImage(":/marine/buoy.png"));
-	_points[0x1020b] = Point(QImage(":/marine/buoy.png"));
-	_points[0x1020d] = Point(QImage(":/marine/light-platform.png"));
-	_points[0x1020e] = Point(QImage(":/marine/beacon.png"));
-	_points[0x1020f] = Point(QImage(":/marine/beacon.png"));
-	_points[0x10210] = Point(QImage(":/marine/beacon.png"));
-	_points[0x10211] = Point(QImage(":/marine/beacon.png"));
-	_points[0x10212] = Point(QImage(":/marine/beacon.png"));
-	_points[0x10213] = Point(QImage(":/marine/beacon.png"));
-	_points[0x10214] = Point(QImage(":/marine/beacon.png"));
-	_points[0x10215] = Point(QImage(":/marine/beacon.png"));
-	_points[0x10216] = Point(QImage(":/marine/mooring-buoy.png"));
-	_points[0x10305] = Point(QImage(":/marine/chimney.png"));
+	_points[0x10100] = Point(QImage(":/marine/light-major.png"), QPoint(8, -8));
+	_points[0x10101] = Point(QImage(":/marine/light-major.png"), QPoint(8, -8));
+	_points[0x10102] = Point(QImage(":/marine/light-major.png"), QPoint(8, -8));
+	_points[0x10103] = Point(QImage(":/marine/light-major.png"), QPoint(8, -8));
+	_points[0x10104] = Point(QImage(":/marine/light-major.png"), QPoint(8, -8));
+	_points[0x10105] = Point(QImage(":/marine/light-major.png"), QPoint(8, -8));
+	_points[0x10106] = Point(QImage(":/marine/light-major.png"), QPoint(8, -8));
+	_points[0x10107] = Point(QImage(":/marine/light-major.png"), QPoint(8, -8));
+	_points[0x10108] = Point(QImage(":/marine/light-major.png"), QPoint(8, -8));
+	_points[0x10109] = Point(QImage(":/marine/light-major.png"), QPoint(8, -8));
+	_points[0x1010a] = Point(QImage(":/marine/light-major.png"), QPoint(8, -8));
+	_points[0x10200] = Point(QImage(":/marine/buoy.png"), QPoint(6, -6));
+	_points[0x10201] = Point(QImage(":/marine/buoy.png"), QPoint(6, -6));
+	_points[0x10202] = Point(QImage(":/marine/buoy.png"), QPoint(6, -6));
+	_points[0x10203] = Point(QImage(":/marine/buoy.png"), QPoint(6, -6));
+	_points[0x10204] = Point(QImage(":/marine/buoy.png"), QPoint(6, -6));
+	_points[0x10205] = Point(QImage(":/marine/buoy.png"), QPoint(6, -6));
+	_points[0x10206] = Point(QImage(":/marine/beacon.png"), QPoint(0, -8));
+	_points[0x10207] = Point(QImage(":/marine/spar-buoy.png"), QPoint(2, -9));
+	_points[0x10209] = Point(QImage(":/marine/buoy.png"), QPoint(6, -6));
+	_points[0x1020a] = Point(QImage(":/marine/buoy.png"), QPoint(6, -6));
+	_points[0x1020b] = Point(QImage(":/marine/buoy.png"), QPoint(6, -6));
+	_points[0x1020d] = Point(QImage(":/marine/light-platform.png"),
+	  QPoint(8, -8));
+	_points[0x1020e] = Point(QImage(":/marine/beacon.png"), QPoint(0, -8));
+	_points[0x1020f] = Point(QImage(":/marine/beacon.png"), QPoint(0, -8));
+	_points[0x10210] = Point(QImage(":/marine/beacon.png"), QPoint(0, -8));
+	_points[0x10211] = Point(QImage(":/marine/beacon.png"), QPoint(0, -8));
+	_points[0x10212] = Point(QImage(":/marine/beacon.png"), QPoint(0, -8));
+	_points[0x10213] = Point(QImage(":/marine/beacon.png"), QPoint(0, -8));
+	_points[0x10214] = Point(QImage(":/marine/beacon.png"), QPoint(0, -8));
+	_points[0x10215] = Point(QImage(":/marine/beacon.png"), QPoint(0, -8));
+	_points[0x10216] = Point(QImage(":/marine/mooring-buoy.png"), QPoint(0, -5));
+	_points[0x10305] = Point(QImage(":/marine/chimney.png"), QPoint(0, -11));
 	_points[0x10306] = Point(QImage(":/marine/church.png"));
 	_points[0x10307] = Point(QImage(":/marine/silo.png"));
-	_points[0x10308] = Point(QImage(":/marine/tower.png"));
+	_points[0x10308] = Point(QImage(":/marine/tower.png"), QPoint(0, -11));
 	_points[0x1030a] = Point(QImage(":/marine/triangulation-point.png"));
 	_points[0x1030b] = Point(QImage(":/marine/radio.png"));
 	_points[0x10400] = Point(QImage(":/marine/obstruction.png"));
 	_points[0x10401] = Point(QImage(":/marine/obstruction.png"));
 	_points[0x10402] = Point(QImage(":/marine/wreck.png"));
-	_points[0x10403] = Point(QImage(":/marine/wreck-exposed.png"));
+	_points[0x10403] = Point(QImage(":/marine/wreck-exposed.png"), QPoint(0, -4));
 	_points[0x10408] = Point(QImage(":/marine/obstruction-covers.png"));
 	_points[0x1040a] = Point(QImage(":/marine/rock-dangerous.png"));
 	_points[0x1040c] = Point(QImage(":/marine/rock-exposed.png"));
